@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -394,14 +394,16 @@ class AdBlockSubscription(QObject):
         self.__downloading = FollowRedirectReply(
             self.location(),
             Helpviewer.HelpWindow.HelpWindow.networkAccessManager())
-        self.__downloading.finished.connect(self.__rulesDownloaded)
+        self.__downloading.finished.connect(
+            lambda: self.__rulesDownloaded(self.__downloading))
     
-    def __rulesDownloaded(self):
+    def __rulesDownloaded(self, reply):
         """
         Private slot to deal with the downloaded rules.
-        """
-        reply = self.sender()
         
+        @param reply reference to the network reply
+        @type QNetworkReply
+        """
         response = reply.readAll()
         reply.close()
         self.__downloading = None
