@@ -47,6 +47,8 @@ class AboutPlugin(QObject):
         """
         super(AboutPlugin, self).__init__(ui)
         self.__ui = ui
+        
+        self.__aboutDialog = None
 
     def activate(self):
         """
@@ -126,8 +128,9 @@ class AboutPlugin(QObject):
         Private slot to handle the About dialog.
         """
         from AboutPlugin.AboutDialog import AboutDialog
-        dlg = AboutDialog(self.__ui)
-        dlg.exec_()
+        if self.__aboutDialog is None:
+            self.__aboutDialog = AboutDialog(self.__ui)
+        self.__aboutDialog.show()
         
     def __aboutQt(self):
         """
