@@ -84,7 +84,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
         self.menu = QMenu(self)
         if self.project.getProjectType() in \
                 ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-                 "PySide", "PySideC"]:
+                 "PySide", "PySideC", "PySide2", "PySideC2"]:
             self.menu.addAction(
                 self.tr('Compile resource'),
                 self.__compileResource)
@@ -120,7 +120,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
         self.menu.addSeparator()
         if self.project.getProjectType() in \
                 ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-                 "PySide", "PySideC"]:
+                 "PySide", "PySideC", "PySide2", "PySideC2"]:
             self.menu.addAction(
                 self.tr('New resource...'), self.__newResource)
         else:
@@ -148,7 +148,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
         self.backMenu = QMenu(self)
         if self.project.getProjectType() in \
                 ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-                 "PySide", "PySideC"]:
+                 "PySide", "PySideC", "PySide2", "PySideC2"]:
             self.backMenu.addAction(
                 self.tr('Compile all resources'),
                 self.__compileAllResources)
@@ -186,7 +186,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
         self.multiMenu = QMenu(self)
         if self.project.getProjectType() in \
                 ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-                 "PySide", "PySideC"]:
+                 "PySide", "PySideC", "PySide2", "PySideC2"]:
             act = self.multiMenu.addAction(
                 self.tr('Compile resources'),
                 self.__compileSelectedResources)
@@ -218,7 +218,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
         self.dirMenu = QMenu(self)
         if self.project.getProjectType() in \
                 ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-                 "PySide", "PySideC"]:
+                 "PySide", "PySideC", "PySide2", "PySideC2"]:
             self.dirMenu.addAction(
                 self.tr('Compile all resources'),
                 self.__compileAllResources)
@@ -259,7 +259,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
         self.dirMultiMenu = QMenu(self)
         if self.project.getProjectType() in \
                 ["Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-                 "PySide", "PySideC"]:
+                 "PySide", "PySideC", "PySide2", "PySideC2"]:
             self.dirMultiMenu.addAction(
                 self.tr('Compile all resources'),
                 self.__compileAllResources)
@@ -527,7 +527,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
     def __readStdout(self):
         """
         Private slot to handle the readyReadStandardOutput signal of the
-        pyrcc4/pyrcc5/pyside-rcc/rbrcc process.
+        pyrcc4/pyrcc5/pyside-rcc/pyside2-rcc/rbrcc process.
         """
         if self.compileProc is None:
             return
@@ -541,7 +541,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
     def __readStderr(self):
         """
         Private slot to handle the readyReadStandardError signal of the
-        pyrcc4/pyrcc5/pyside-rcc/rbrcc process.
+        pyrcc4/pyrcc5/pyside-rcc/pyside2-rcc/rbrcc process.
         """
         if self.compileProc is None:
             return
@@ -651,7 +651,15 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
                     self.rccCompiler = Utilities.generatePyQtToolPath('pyrcc5')
             elif self.project.getProjectType() in ["PySide", "PySideC"]:
                 self.rccCompiler = Utilities.generatePySideToolPath(
-                    'pyside-rcc')
+                    'pyside-rcc', "1")
+                if self.project.getProjectLanguage() in \
+                        ["Python", "Python2"]:
+                    args.append("-py2")
+                else:
+                    args.append("-py3")
+            elif self.project.getProjectType() in ["PySide2", "PySide2C"]:
+                self.rccCompiler = Utilities.generatePySideToolPath(
+                    'pyside2-rcc', "2")
                 if self.project.getProjectLanguage() in \
                         ["Python", "Python2"]:
                     args.append("-py2")
