@@ -175,7 +175,7 @@ class OpenSearchManager(QObject):
         from WebBrowser.WebBrowserWindow import WebBrowserWindow
 
         reply = WebBrowserWindow.networkManager().get(QNetworkRequest(url))
-        reply.finished.connect(self.__engineFromUrlAvailable)
+        reply.finished.connect(lambda: self.__engineFromUrlAvailable(reply))
         reply.setParent(self)
         self.__replies.append(reply)
         
@@ -473,39 +473,38 @@ class OpenSearchManager(QObject):
                 """Searches on: {1}</p>""").format(engine.name(), host))
         return res
     
-    def __engineFromUrlAvailable(self):
+    def __engineFromUrlAvailable(self, reply):
         """
         Private slot to add a search engine from the net.
+        
+        @param reply reference to the network reply
+        @type QNetworkReply
         """
-        reply = self.sender()
-        if reply is None:
-            return
-        
-        if reply.error() != QNetworkReply.NoError:
-            reply.close()
-            if reply in self.__replies:
-                self.__replies.remove(reply)
-            return
-        
-        from .OpenSearchReader import OpenSearchReader
-        reader = OpenSearchReader()
-        engine = reader.read(reply)
-        
         reply.close()
         if reply in self.__replies:
             self.__replies.remove(reply)
         
-        if not engine.isValid():
-            return
-        
-        if self.engineExists(engine.name()):
-            return
-        
-        if not self.__confirmAddition(engine):
-            return
-        
-        if not self.__addEngineByEngine(engine):
-            return
+        if reply.error() == QNetworkReply.NoError:
+            from .OpenSearchReader import OpenSearchReader
+            reader = OpenSearchReader()
+            engine = reader.read(reply)
+            
+            if not engine.isValid():
+                return
+            
+            if self.engineExists(engine.name()):
+                return
+            
+            if not self.__confirmAddition(engine):
+                return
+            
+            if not self.__addEngineByEngine(engine):
+                return
+        else:
+            # some error happened
+            from WebBrowser.WebBrowserWindow import WebBrowserWindow
+            WebBrowserWindow.getWindow().statusBar().showMessage(
+                reply.errorString(), 10000)
     
     def convertKeywordSearchToUrl(self, keywordSearch):
         """
