@@ -112,7 +112,7 @@ def main(argv):
     except getopt.GetoptError:
         usage()
 
-    for opt, arg in optlist:
+    for opt, _arg in optlist:
         if opt in ["-h", "--help"]:
             usage(0)
     
